@@ -5,24 +5,28 @@ use strict;
 use warnings 'all';
 
 
-sub new {
+sub new
+{
   return bless { data => '' }, shift;
-}
+}# end new()
 
-sub add {
+sub add
+{
   my ($s, $str) = @_;
   return unless defined($str);
   $s->{data} .= $str;
   return;
-}
-sub data { shift->{data} }
-sub clear {shift->{data} = '' }
+}# end add()
 
-sub DESTROY {
+sub data  { shift->{data} }
+sub clear { shift->{data} = '' }
+
+sub DESTROY
+{
   my $s = shift;
   delete($s->{data});
   undef(%$s);
-}
+}# end DESTROY()
 
 1;# return true:
 
